==> pdfedit-0.3.2.tar.bz2: pdfedit-0.3.2/src/kernel/cobject.h <==
/*                                                                              
 * PDFedit - free program for PDF document manipulation.                        
 * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
 *                                              Miroslav Jahoda,       
 *                                              Jozef Misutka, 
 *                                              Martin Petricek                                             
 *
 * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
 */ 
// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
/* 
 * =====================================================================================
 *        Filename:  cobject.h
 *     Description:  Header file containing definition of IProperty and CObject classes.
 *         Created:  01/18/2006 
 *          Author:  jmisutka (06/01/19), 
 * =====================================================================================
 */
#ifndef _COBJECT_H
#define _COBJECT_H


//=====================================================================================
// Base class for all cobjects
//=====================================================================================
#include "iproperty.h"

//=====================================================================================
// CObjectSimple
//=====================================================================================
#include "cobjectsimple.h"

//=====================================================================================
// CArray
//=====================================================================================
#include "carray.h"

//=====================================================================================
// CDict
//=====================================================================================
#include "cdict.h"

//=====================================================================================
// CObjectStream
//=====================================================================================
#include "cstream.h"

//=====================================================================================
// CStreamsXpdfReader
//=====================================================================================
#include "cstreamsxpdfreader.h"

//=====================================================================================
// Utility functions not included in previous includes
//=====================================================================================
#include "cobjecthelpers.h"


#endif // _COBJECT_H

==> pdfedit-0.4.1.tar.bz2: pdfedit-0.4.1/src/kernel/cobject.h <==
/*
 * PDFedit - free program for PDF document manipulation.
 * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
 *                                              Miroslav Jahoda,
 *                                              Jozef Misutka,
 *                                              Martin Petricek
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (in doc/LICENSE.GPL); if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 * MA  02111-1307  USA
 *
 * Project is hosted on http://sourceforge.net/projects/pdfedit
 */
// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
#ifndef _COBJECT_H
#define _COBJECT_H


//=====================================================================================
// Base class for all cobjects
//=====================================================================================
#include "kernel/iproperty.h"

//=====================================================================================
// CObjectSimple
//=====================================================================================
#include "kernel/cobjectsimple.h"

//=====================================================================================
// CArray
//=====================================================================================
#include "kernel/carray.h"

//=====================================================================================
// CDict
//=====================================================================================
#include "kernel/cdict.h"

//=====================================================================================
// CObjectStream
//=====================================================================================
#include "kernel/cstream.h"

//=====================================================================================
// CStreamsXpdfReader
//=====================================================================================
#include "kernel/cstreamsxpdfreader.h"

//=====================================================================================
// Utility functions not included in previous includes
//=====================================================================================
#include "kernel/cobjecthelpers.h"


#endif // _COBJECT_H
